@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.4';
+  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.5';
 }
 
 use Moose;
@@ -22,7 +22,7 @@ use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeFromPod;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::DistManifestTests;
-use Dist::Zilla::Plugin::LatestPrereqs;
+use Dist::Zilla::Plugin::Signature;
 
 =head1 NAME
 
@@ -30,7 +30,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version 0.4
+version 0.5
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ This bundle provides the following plugins and bundles:
 	[NextRelease]
 	[ReadmeFromPod]
 	[TestRelease]
-	[LatestPrereqs]
+	[Signature]
 
 =head1 INTERNAL METHODS
 
@@ -96,7 +96,7 @@ sub bundle_config {
 		[ CheckChangesHasContent	=> {} ],
 		[ DistManifestTests		=> {} ],
 		[ TestRelease			=> {} ],
-		[ LatestPrereqs			=> {} ],
+		[ Signature			=> {} ],
 	);
 
 	push (@plugins, @extra);
